.. _polys-docs:

========================
Polynomials Manipulation
========================

Computations with polynomials are at the core of computer algebra and
having a fast and robust polynomials manipulation module is a key for
building a powerful symbolic manipulation system. Diofant has a dedicated
module :mod:`diofant.polys` for computing in polynomial algebras over
various coefficient domains.

There is a vast number of methods implemented, ranging from simple tools
like polynomial division, to advanced concepts including Gröbner bases
and multivariate factorization over algebraic number domains.

.. toctree::
    :caption: Contents
    :name: polytoc
    :maxdepth: 3

    basics.rst
    wester.rst
    reference.rst
    literature.rst
